// You can paste this directly into Xcode's Playground (Xcode 10.1, Swift 4)
import UIKit

let jsonData = """
{
    "listener": "you",
    "results": {
        "playlist": [
            {
                "composer": "Villa-Lobos",
                "title": "Bachianas Brasileiras No. 5"
            }
        ]
    }
}
""".data(using: .utf8)!

// A playlist item
struct MusicalPiece: Codable {
    let composer: String
    let title: String
}

struct Response: Decodable {
    let listener: String
    let playlist: [MusicalPiece]

    enum CodingKeys: String, CodingKey {
        case listener
        case results
        case playlist
    }

    init(from decoder: Decoder) throws {
        let container = try decoder.container(keyedBy: CodingKeys.self)
        self.listener = try container.decode(String.self, forKey: .listener)

        let results = try container.nestedContainer(keyedBy:
            CodingKeys.self, forKey: .results)
        self.playlist = try results.decode([MusicalPiece].self, forKey: .playlist)
    }
}

// Initializes a Response object from the JSON data at the top.
let response = try! JSONDecoder().decode(Response.self, from: jsonData)

// Instead of: response.results.playlist
print(response.playlist)
print(response.listener)

// Instead of: response.results.playlist.first?.composer
print(response.playlist.first?.composer)

// Instead of: response.results.playlist.first?.title
print(response.playlist.first?.title)